@@ -1,13 +1,18 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
-use serde::{Deserialize, Serialize};
 
-use crate::parser::DocParser;
+use deno_ast::ParsedSource;
+use serde::Deserialize;
+use serde::Serialize;
+
+use crate::js_doc::JsDoc;
+use crate::swc_util::js_doc_for_span;
 
 #[derive(Debug, Serialize, Deserialize, Clone)]
 #[serde(rename_all = "camelCase")]
 pub struct EnumMemberDef {
   pub name: String,
-  pub js_doc: Option<String>,
+  #[serde(skip_serializing_if = "JsDoc::is_empty")]
+  pub js_doc: JsDoc,
 }
 
 #[derive(Debug, Serialize, Deserialize, Clone)]
@@ -17,16 +22,16 @@ pub struct EnumDef {
 }
 
 pub fn get_doc_for_ts_enum_decl(
-  doc_parser: &DocParser,
-  enum_decl: &swc_ecmascript::ast::TsEnumDecl,
+  parsed_source: &ParsedSource,
+  enum_decl: &deno_ast::swc::ast::TsEnumDecl,
 ) -> (String, EnumDef) {
   let enum_name = enum_decl.id.sym.to_string();
   let mut members = vec![];
 
   for enum_member in &enum_decl.members {
-    use swc_ecmascript::ast::TsEnumMemberId::*;
+    use deno_ast::swc::ast::TsEnumMemberId::*;
 
-    let member_js_doc = doc_parser.js_doc_for_span(enum_member.span);
+    let member_js_doc = js_doc_for_span(parsed_source, &enum_member.span);
 
     let member_name = match &enum_member.id {
       Ident(ident) => ident.sym.to_string(),
