@@ -1,5 +1,6 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
 
+use deno_ast::swc::common::comments::Comment;
 use deno_ast::swc::common::comments::CommentKind;
 use deno_ast::swc::common::comments::Comments;
 use deno_ast::swc::common::BytePos;
@@ -8,13 +9,29 @@ use deno_ast::ParsedSource;
 use regex::Regex;
 
 use crate::js_doc::JsDoc;
+use crate::js_doc::JsDocTag;
 use crate::node::Location;
 
 lazy_static! {
   static ref JS_DOC_RE: Regex = Regex::new(r#"\s*\* ?"#).unwrap();
 }
 
-pub fn js_doc_for_span(parsed_source: &ParsedSource, span: &Span) -> JsDoc {
+fn parse_js_doc(js_doc_comment: &Comment) -> JsDoc {
+  let txt = js_doc_comment
+    .text
+    .split('\n')
+    .map(|line| JS_DOC_RE.replace(line, "").to_string())
+    .collect::<Vec<String>>()
+    .join("\n")
+    .trim()
+    .to_string();
+  txt.into()
+}
+
+pub(crate) fn js_doc_for_span(
+  parsed_source: &ParsedSource,
+  span: &Span,
+) -> JsDoc {
   let comments = parsed_source
     .comments()
     .get_leading(span.lo())
@@ -22,44 +39,34 @@ pub fn js_doc_for_span(parsed_source: &ParsedSource, span: &Span) -> JsDoc {
   if let Some(js_doc_comment) = comments.iter().rev().find(|comment| {
     comment.kind == CommentKind::Block && comment.text.starts_with('*')
   }) {
-    // todo(dsherret): I've inlined the `source_map.span_to_margin` swc code
-    // here after removing the usage of swc's source map, but it seems strange and
-    // no tests fail if this is removed. We should look to improve this and
-    // add a test in the future.
-    let mut margin_pat = String::from("");
-    let span_text = parsed_source.source().get_span_text(span);
-    if let Some(margin) = span_text
-      .split('\n')
-      .last()
-      .map(|last_line| last_line.len() - last_line.trim_start().len())
-    {
-      for _ in 0..margin {
-        margin_pat.push(' ');
-      }
-    }
-
-    let txt = js_doc_comment
-      .text
-      .split('\n')
-      .map(|line| JS_DOC_RE.replace(line, "").to_string())
-      .map(|line| {
-        if line.starts_with(&margin_pat) {
-          line[margin_pat.len()..].to_string()
-        } else {
-          line
-        }
-      })
-      .collect::<Vec<String>>()
-      .join("\n");
-
-    let txt = txt.trim_start().trim_end().to_string();
-
-    txt.into()
+    parse_js_doc(js_doc_comment)
   } else {
     JsDoc::default()
   }
 }
 
+/// Inspects leading comments in the source and returns the first JSDoc comment
+/// with a `@module` tag along with its associated span, otherwise returns
+/// `None`.
+pub(crate) fn module_js_doc_for_source(
+  parsed_source: &ParsedSource,
+) -> Option<(JsDoc, Span)> {
+  let comments = parsed_source.get_leading_comments();
+  if let Some(js_doc_comment) = comments.iter().find(|comment| {
+    comment.kind == CommentKind::Block && comment.text.starts_with('*')
+  }) {
+    let leading_js_doc = parse_js_doc(js_doc_comment);
+    if leading_js_doc
+      .tags
+      .iter()
+      .any(|tag| *tag == JsDocTag::Module)
+    {
+      return Some((leading_js_doc, js_doc_comment.span));
+    }
+  }
+  None
+}
+
 pub fn get_location(parsed_source: &ParsedSource, pos: BytePos) -> Location {
   // todo(#150): for some reason we're using a display indent width of 4
   let line_and_column_index = parsed_source
